# Shuttle Radar Topography Mission (SRTM) Digital Elevation Model (DEM) search and download utility

This Python package provides utilities for searching and downloading Digital Elevatiom Model (DEM) data from the NASADEM Shuttle Radar Topography Mission (SRTM) dataset.

[Gregory H. Halverson](https://github.com/gregory-halverson-jpl) (they/them)<br>
[gregory.h.halverson@jpl.nasa.gov](mailto:gregory.h.halverson@jpl.nasa.gov)<br>
NASA Jet Propulsion Laboratory 329G

## References

- NASA JPL. (2013). *Shuttle Radar Topography Mission (SRTM) Digital Elevation Model (DEM)*. NASA Earthdata. Retrieved from [https://earthdata.nasa.gov](https://earthdata.nasa.gov).
- Farr, T. G., Rosen, P. A., Caro, E., Crippen, R., Duren, R., Hensley, S., ... & Alsdorf, D. (2007). The Shuttle Radar Topography Mission. *Reviews of Geophysics*, 45(2), RG2004. [https://doi.org/10.1029/2005RG000183](https://doi.org/10.1029/2005RG000183)
- NASADEM Data Product. (2020). NASA Jet Propulsion Laboratory. Retrieved from [https://doi.org/10.5067/MEaSUREs/NASADEM/NASADEM_HGT.001](https://doi.org/10.5067/MEaSUREs/NASADEM/NASADEM_HGT.001)
